pub unsafe extern "C" fn fdt_appendprop(
fdt: *mut c_void,
nodeoffset: c_int,
name: *const c_char,
val: *const c_void,
len: c_int,
) -> c_intExpand description
fdt_appendprop - append to or create a property @fdt: pointer to the device tree blob @nodeoffset: offset of the node whose property to change @name: name of the property to append to @val: pointer to data to append to the property value @len: length of the data to append to the property value
fdt_appendprop() appends the value to the named property in the given node, creating the property if it does not already exist.
This function may insert data into the blob, and will therefore change the offsets of some existing nodes.
returns: 0, on success -FDT_ERR_NOSPACE, there is insufficient free space in the blob to contain the new property value -FDT_ERR_BADOFFSET, nodeoffset did not point to FDT_BEGIN_NODE tag -FDT_ERR_BADLAYOUT, -FDT_ERR_BADMAGIC, -FDT_ERR_BADVERSION, -FDT_ERR_BADSTATE, -FDT_ERR_BADSTRUCTURE, -FDT_ERR_BADLAYOUT, -FDT_ERR_TRUNCATED, standard meanings