fdt_create_with_flags

Function fdt_create_with_flags 

pub unsafe extern "C" fn fdt_create_with_flags(
    buf: *mut c_void,
    bufsize: c_int,
    flags: u32,
) -> c_int
fdt_create_with_flags - begin creation of a new fdt @buf: pointer to memory allocated where fdt will be created @bufsize: size of the memory space at fdt @flags: a valid combination of FDT_CREATE_FLAG_ flags, or 0.

fdt_create_with_flags() begins the process of creating a new fdt with the sequential write interface.

fdt creation process must end with fdt_finish() to produce a valid fdt.

returns: 0, on success -FDT_ERR_NOSPACE, bufsize is insufficient for a minimal fdt -FDT_ERR_BADFLAGS, flags is not valid