fdt_del_node

Function fdt_del_node 

pub unsafe extern "C" fn fdt_del_node(
    fdt: *mut c_void,
    nodeoffset: c_int,
) -> c_int
fdt_del_node - delete a node (subtree) @fdt: pointer to the device tree blob @nodeoffset: offset of the node to nop

fdt_del_node() will remove the given node, including all its subnodes if any, from the blob.

This function will delete data from the blob, and will therefore change the offsets of some existing nodes.

returns: 0, on success -FDT_ERR_BADOFFSET, nodeoffset did not point to FDT_BEGIN_NODE tag -FDT_ERR_BADLAYOUT, -FDT_ERR_BADMAGIC, -FDT_ERR_BADVERSION, -FDT_ERR_BADSTATE, -FDT_ERR_BADSTRUCTURE, -FDT_ERR_TRUNCATED, standard meanings