fdt_delprop

Function fdt_delprop 

pub unsafe extern "C" fn fdt_delprop(
    fdt: *mut c_void,
    nodeoffset: c_int,
    name: *const c_char,
) -> c_int
fdt_delprop - delete a property @fdt: pointer to the device tree blob @nodeoffset: offset of the node whose property to nop @name: name of the property to nop

fdt_delprop() will delete the given property.

This function will delete data from the blob, and will therefore change the offsets of some existing nodes.

returns: 0, on success -FDT_ERR_NOTFOUND, node does not have the named property -FDT_ERR_BADOFFSET, nodeoffset did not point to FDT_BEGIN_NODE tag -FDT_ERR_BADLAYOUT, -FDT_ERR_BADMAGIC, -FDT_ERR_BADVERSION, -FDT_ERR_BADSTATE, -FDT_ERR_BADSTRUCTURE, -FDT_ERR_TRUNCATED, standard meanings