pub unsafe extern "C" fn fdt_end_node(fdt: *mut c_void) -> c_intExpand description
fdt_end_node - complete the current node @fdt: Pointer to the device tree blob
fdt_end_node() completes the current node during sequential write. This function must be called to close each node started with fdt_begin_node(). After calling this function, no more properties or subnodes can be added to the node.
returns: 0, on success -FDT_ERR_BADSTATE, if not currently within a node