fdt_finish

Function fdt_finish 

pub unsafe extern "C" fn fdt_finish(fdt: *mut c_void) -> c_int
fdt_finish - complete device tree creation @fdt: Pointer to the device tree blob

fdt_finish() completes the device tree creation process started with fdt_create(). This function finalizes the device tree blob and makes it ready for use. After calling this function, the blob is complete and can be used with libfdt read-only and read-write functions, but not with sequential write functions.

returns: 0, on success -FDT_ERR_BADSTATE, if the sequential write process is incomplete