fdt_first_property_offset

Function fdt_first_property_offset 

pub unsafe extern "C" fn fdt_first_property_offset(
    fdt: *const c_void,
    nodeoffset: c_int,
) -> c_int
fdt_first_property_offset - find the offset of a node’s first property @fdt: pointer to the device tree blob @nodeoffset: structure block offset of a node

fdt_first_property_offset() finds the first property of the node at the given structure block offset.

returns: structure block offset of the property (>=0), on success -FDT_ERR_NOTFOUND, if the requested node has no properties -FDT_ERR_BADOFFSET, if nodeoffset did not point to an FDT_BEGIN_NODE tag -FDT_ERR_BADMAGIC, -FDT_ERR_BADVERSION, -FDT_ERR_BADSTATE, -FDT_ERR_BADSTRUCTURE, -FDT_ERR_TRUNCATED, standard meanings.