fdt_generate_phandle

Function fdt_generate_phandle 

pub unsafe extern "C" fn fdt_generate_phandle(
    fdt: *const c_void,
    phandle: *mut u32,
) -> c_int
fdt_generate_phandle - return a new, unused phandle for a device tree blob @fdt: pointer to the device tree blob @phandle: return location for the new phandle

Walks the device tree blob and looks for the highest phandle value. On success, the new, unused phandle value (one higher than the previously highest phandle value in the device tree blob) will be returned in the @phandle parameter.

returns: 0 on success or a negative error-code on failure