pub unsafe extern "C" fn fdt_get_name(
fdt: *const c_void,
nodeoffset: c_int,
lenp: *mut c_int,
) -> *const c_charExpand description
fdt_get_name - retrieve the name of a given node @fdt: pointer to the device tree blob @nodeoffset: structure block offset of the starting node @lenp: pointer to an integer variable (will be overwritten) or NULL
fdt_get_name() retrieves the name (including unit address) of the device tree node at structure block offset nodeoffset. If lenp is non-NULL, the length of this name is also returned, in the integer pointed to by lenp.
returns: pointer to the node’s name, on success If lenp is non-NULL, *lenp contains the length of that name (>=0) NULL, on error if lenp is non-NULL *lenp contains an error code (<0): -FDT_ERR_BADOFFSET, nodeoffset did not point to FDT_BEGIN_NODE tag -FDT_ERR_BADMAGIC, -FDT_ERR_BADVERSION, -FDT_ERR_BADSTATE, standard meanings