pub unsafe extern "C" fn fdt_get_property(
fdt: *const c_void,
nodeoffset: c_int,
name: *const c_char,
lenp: *mut c_int,
) -> *const fdt_propertyExpand description
fdt_get_property - find a given property in a given node @fdt: pointer to the device tree blob @nodeoffset: offset of the node whose property to find @name: name of the property to find @lenp: pointer to an integer variable (will be overwritten) or NULL
fdt_get_property() retrieves a pointer to the fdt_property structure within the device tree blob corresponding to the property named ‘name’ of the node at offset nodeoffset. If lenp is non-NULL, the length of the property value is also returned, in the integer pointed to by lenp.
returns: pointer to the structure representing the property if lenp is non-NULL, *lenp contains the length of the property value (>=0) NULL, on error if lenp is non-NULL, *lenp contains an error code (<0): -FDT_ERR_NOTFOUND, node does not have named property -FDT_ERR_BADOFFSET, nodeoffset did not point to FDT_BEGIN_NODE tag -FDT_ERR_BADMAGIC, -FDT_ERR_BADVERSION, -FDT_ERR_BADSTATE, -FDT_ERR_BADSTRUCTURE, -FDT_ERR_TRUNCATED, standard meanings