pub unsafe extern "C" fn fdt_get_symbol(
fdt: *const c_void,
name: *const c_char,
) -> *const c_charExpand description
fdt_get_symbol - retrieve the path referenced by a given symbol @fdt: pointer to the device tree blob @name: name of the symbol to look up
fdt_get_symbol() retrieves the value of a given symbol. That is, the value of the property named @name in the node /symbols. Such a node exists only for a device tree blob that has been compiled with the -@ dtc option. Each property corresponds to a label appearing in the device tree source, with the name of the property being the label and the value being the full path of the node it is attached to.
returns: a pointer to the expansion of the symbol named ‘name’, if it exists NULL, if the given symbol or the /symbols node does not exist