pub unsafe extern "C" fn fdt_next_property_offset(
fdt: *const c_void,
offset: c_int,
) -> c_intExpand description
fdt_next_property_offset - step through a node’s properties @fdt: pointer to the device tree blob @offset: structure block offset of a property
fdt_next_property_offset() finds the property immediately after the one at the given structure block offset. This will be a property of the same node as the given property.
returns: structure block offset of the next property (>=0), on success -FDT_ERR_NOTFOUND, if the given property is the last in its node -FDT_ERR_BADOFFSET, if nodeoffset did not point to an FDT_PROP tag -FDT_ERR_BADMAGIC, -FDT_ERR_BADVERSION, -FDT_ERR_BADSTATE, -FDT_ERR_BADSTRUCTURE, -FDT_ERR_TRUNCATED, standard meanings.