fdt_nop_node

Function fdt_nop_node 

pub unsafe extern "C" fn fdt_nop_node(
    fdt: *mut c_void,
    nodeoffset: c_int,
) -> c_int
fdt_nop_node - replace a node (subtree) with nop tags @fdt: pointer to the device tree blob @nodeoffset: offset of the node to nop

fdt_nop_node() will replace a given node’s representation in the blob, including all its subnodes, if any, with FDT_NOP tags, effectively removing it from the tree.

This function will alter only the bytes in the blob which contain the node and its properties and subnodes, and will not alter or move any other part of the tree.

returns: 0, on success -FDT_ERR_BADOFFSET, nodeoffset did not point to FDT_BEGIN_NODE tag -FDT_ERR_BADMAGIC, -FDT_ERR_BADVERSION, -FDT_ERR_BADSTATE, -FDT_ERR_BADSTRUCTURE, -FDT_ERR_TRUNCATED, standard meanings