fdt_open_into

Function fdt_open_into 

pub unsafe extern "C" fn fdt_open_into(
    fdt: *const c_void,
    buf: *mut c_void,
    bufsize: c_int,
) -> c_int
fdt_open_into - move a device tree into a new buffer and make editable @fdt: Pointer to the device tree to move @buf: Buffer where the editable tree should be placed @bufsize: Size of the buffer at @buf

fdt_open_into() moves and reorganizes the device tree blob from @fdt into @buf, converting it to a format suitable for read-write operations. The new buffer should allow space for modifications.

returns: 0, on success -FDT_ERR_NOSPACE, if @bufsize is too small -FDT_ERR_BADMAGIC, -FDT_ERR_BADVERSION, -FDT_ERR_BADSTATE, -FDT_ERR_BADSTRUCTURE, -FDT_ERR_TRUNCATED, standard meanings