fdt_pack

Function fdt_pack 

pub unsafe extern "C" fn fdt_pack(fdt: *mut c_void) -> c_int
fdt_pack - pack a device tree blob @fdt: Pointer to the device tree blob

fdt_pack() reorganizes the device tree blob to eliminate any free space and pack it into the minimum possible size. This is useful after making modifications that might have left gaps in the blob.

returns: 0, on success -FDT_ERR_BADMAGIC, -FDT_ERR_BADVERSION, -FDT_ERR_BADSTATE, -FDT_ERR_BADSTRUCTURE, -FDT_ERR_BADLAYOUT, standard meanings