fdt_property

Function fdt_property 

pub unsafe extern "C" fn fdt_property(
    fdt: *mut c_void,
    name: *const c_char,
    val: *const c_void,
    len: c_int,
) -> c_int
fdt_property - add a property to the current node @fdt: Pointer to the device tree blob @name: Name of the property to add @val: Pointer to the property value @len: Length of the property value in bytes

fdt_property() adds a property with the given @name and value to the current node during sequential write. This function can only be called between fdt_begin_node() and fdt_end_node().

returns: 0, on success -FDT_ERR_NOSPACE, if there is insufficient space in the blob -FDT_ERR_BADSTATE, if not currently within a node