fdt_size_cells

Function fdt_size_cells 

pub unsafe extern "C" fn fdt_size_cells(
    fdt: *const c_void,
    nodeoffset: c_int,
) -> c_int
fdt_size_cells - retrieve address range size for a bus represented in the tree @fdt: pointer to the device tree blob @nodeoffset: offset of the node to find the address range size for

When the node has a valid #size-cells property, returns its value.

returns: 0 <= n < FDT_MAX_NCELLS, on success 1, if the node has no #size-cells property -FDT_ERR_BADNCELLS, if the node has a badly formatted or invalid #size-cells property -FDT_ERR_BADMAGIC, -FDT_ERR_BADVERSION, -FDT_ERR_BADSTATE, -FDT_ERR_BADSTRUCTURE, -FDT_ERR_TRUNCATED, standard meanings