fdt_string

Function fdt_string 

pub unsafe extern "C" fn fdt_string(
    fdt: *const c_void,
    stroffset: c_int,
) -> *const c_char
fdt_string - retrieve a string from the strings block of a device tree @fdt: pointer to the device tree blob @stroffset: offset of the string within the strings block (native endian)

fdt_string() retrieves a pointer to a single string from the strings block of the device tree blob at fdt.

returns: a pointer to the string, on success NULL, if stroffset is out of bounds, or doesn’t point to a valid string