fdt_stringlist_count

Function fdt_stringlist_count 

pub unsafe extern "C" fn fdt_stringlist_count(
    fdt: *const c_void,
    nodeoffset: c_int,
    property: *const c_char,
) -> c_int
fdt_stringlist_count - count the number of strings in a string list @fdt: pointer to the device tree blob @nodeoffset: offset of a tree node @property: name of the property containing the string list

returns: the number of strings in the given property -FDT_ERR_BADVALUE if the property value is not NUL-terminated -FDT_ERR_NOTFOUND if the property does not exist