pub unsafe extern "C" fn fdt_add_reservemap_entry(
fdt: *mut c_void,
addr: u64,
size: u64,
) -> c_intExpand description
fdt_add_reservemap_entry - add an entry to the memory reserve map @fdt: Pointer to the device tree blob @addr: Start address of the reserve map entry @size: Size of the reserved region
fdt_add_reservemap_entry() adds a memory reserve map entry to the device tree blob during the sequential write process. This function can only be called after fdt_create() and before fdt_finish_reservemap().
returns: 0, on success -FDT_ERR_NOSPACE, if there is insufficient space in the blob -FDT_ERR_BADSTATE, if not in the correct sequential write state