pub unsafe extern "C" fn fdt_add_subnode(
fdt: *mut c_void,
parentoffset: c_int,
name: *const c_char,
) -> c_intExpand description
fdt_add_subnode - creates a new node @fdt: pointer to the device tree blob @parentoffset: structure block offset of a node @name: name of the subnode to locate
fdt_add_subnode() creates a new node as a subnode of the node at structure block offset parentoffset, with the given name (which should include the unit address, if any).
This function will insert data into the blob, and will therefore change the offsets of some existing nodes.
returns: structure block offset of the created subnode (>=0), on success -FDT_ERR_NOTFOUND, if the requested subnode does not exist -FDT_ERR_BADOFFSET, if parentoffset did not point to an FDT_BEGIN_NODE tag -FDT_ERR_EXISTS, if the node at parentoffset already has a subnode of the given name -FDT_ERR_NOSPACE, if there is insufficient free space in the blob to contain the new node -FDT_ERR_NOSPACE -FDT_ERR_BADLAYOUT -FDT_ERR_BADMAGIC, -FDT_ERR_BADVERSION, -FDT_ERR_BADSTATE, -FDT_ERR_BADSTRUCTURE, -FDT_ERR_TRUNCATED, standard meanings.