pub unsafe extern "C" fn fdt_begin_node(
fdt: *mut c_void,
name: *const c_char,
) -> c_intExpand description
fdt_begin_node - start creation of a new node @fdt: Pointer to the device tree blob @name: Name of the node to create
fdt_begin_node() starts the creation of a new node with the given @name during sequential write. After calling this function, properties can be added with fdt_property() and subnodes can be created with additional fdt_begin_node() calls. The node must be completed with fdt_end_node().
returns: 0, on success -FDT_ERR_NOSPACE, if there is insufficient space in the blob -FDT_ERR_BADSTATE, if not in the correct sequential write state