pub unsafe extern "C" fn fdt_check_header(fdt: *const c_void) -> c_intExpand description
fdt_check_header - sanity check a device tree header @fdt: pointer to data which might be a flattened device tree
fdt_check_header() checks that the given buffer contains what appears to be a flattened device tree, and that the header contains valid information (to the extent that can be determined from the header alone).
returns: 0, if the buffer appears to contain a valid device tree -FDT_ERR_BADMAGIC, -FDT_ERR_BADVERSION, -FDT_ERR_BADSTATE, -FDT_ERR_TRUNCATED, standard meanings, as above