pub unsafe extern "C" fn fdt_create_empty_tree(
buf: *mut c_void,
bufsize: c_int,
) -> c_intExpand description
fdt_create_empty_tree - create an empty device tree @buf: Buffer where the empty tree should be created @bufsize: Size of the buffer at @buf
fdt_create_empty_tree() creates a minimal empty device tree blob in the given buffer. The tree contains only a root node with no properties or subnodes.
returns: 0, on success -FDT_ERR_NOSPACE, if @bufsize is too small for even an empty tree