pub unsafe extern "C" fn fdt_get_alias(
fdt: *const c_void,
name: *const c_char,
) -> *const c_charExpand description
fdt_get_alias - retrieve the path referenced by a given alias @fdt: pointer to the device tree blob @name: name of the alias to look up
fdt_get_alias() retrieves the value of a given alias. That is, the value of the property named @name in the node /aliases.
returns: a pointer to the expansion of the alias named ‘name’, if it exists NULL, if the given alias or the /aliases node does not exist