pub unsafe extern "C" fn fdt_get_mem_rsv(
fdt: *const c_void,
n: c_int,
address: *mut u64,
size: *mut u64,
) -> c_intExpand description
fdt_get_mem_rsv - retrieve one memory reserve map entry @fdt: pointer to the device tree blob @n: index of reserve map entry @address: pointer to 64-bit variable to hold the start address @size: pointer to 64-bit variable to hold the size of the entry
On success, @address and @size will contain the address and size of the n-th reserve map entry from the device tree blob, in native-endian format.
returns: 0, on success -FDT_ERR_BADMAGIC, -FDT_ERR_BADVERSION, -FDT_ERR_BADSTATE, standard meanings