pub unsafe extern "C" fn fdt_get_phandle(
fdt: *const c_void,
nodeoffset: c_int,
) -> u32Expand description
fdt_get_phandle - retrieve the phandle of a given node @fdt: pointer to the device tree blob @nodeoffset: structure block offset of the node
fdt_get_phandle() retrieves the phandle of the device tree node at structure block offset nodeoffset.
returns: the phandle of the node at nodeoffset, on success (!= 0, != -1) 0, if the node has no phandle, or another error occurs