pub unsafe extern "C" fn fdt_get_string(
fdt: *const c_void,
stroffset: c_int,
lenp: *mut c_int,
) -> *const c_charExpand description
fdt_get_string - retrieve a string from the strings block of a device tree @fdt: pointer to the device tree blob @stroffset: offset of the string within the strings block (native endian) @lenp: optional pointer to return the string’s length
fdt_get_string() retrieves a pointer to a single string from the strings block of the device tree blob at fdt, and optionally also returns the string’s length in *lenp.
returns: a pointer to the string, on success NULL, if stroffset is out of bounds, or doesn’t point to a valid string