pub unsafe extern "C" fn fdt_node_offset_by_phandle(
fdt: *const c_void,
phandle: u32,
) -> c_intExpand description
fdt_node_offset_by_phandle - find the node with a given phandle @fdt: pointer to the device tree blob @phandle: phandle value
fdt_node_offset_by_phandle() returns the offset of the node which has the given phandle value. If there is more than one node in the tree with the given phandle (an invalid tree), results are undefined.
returns: structure block offset of the located node (>= 0), on success -FDT_ERR_NOTFOUND, no node with that phandle exists -FDT_ERR_BADPHANDLE, given phandle value was invalid (0 or -1) -FDT_ERR_BADMAGIC, -FDT_ERR_BADVERSION, -FDT_ERR_BADSTATE, -FDT_ERR_BADSTRUCTURE, standard meanings