pub unsafe extern "C" fn fdt_overlay_target_offset(
fdt: *const c_void,
fdto: *const c_void,
fragment_offset: c_int,
pathp: *mut *const c_char,
) -> c_intExpand description
fdt_overlay_target_offset - retrieves the offset of a fragment’s target @fdt: Base device tree blob @fdto: Device tree overlay blob @fragment_offset: node offset of the fragment in the overlay @pathp: pointer which receives the path of the target (or NULL)
fdt_overlay_target_offset() retrieves the target offset in the base device tree of a fragment, no matter how the actual targeting is done (through a phandle or a path)
returns: the targeted node offset in the base device tree Negative error code on error