pub unsafe extern "C" fn fdt_resize(
fdt: *mut c_void,
buf: *mut c_void,
bufsize: c_int,
) -> c_intExpand description
fdt_resize - move and resize a device tree in sequential write state @fdt: Pointer to the device tree to resize @buf: Buffer where resized tree should be placed @bufsize: Size of the buffer at @buf
fdt_resize() moves the device tree blob from @fdt to @buf and resizes it to fit in the new buffer size.
returns: 0, on success -FDT_ERR_NOSPACE, if @bufsize is too small -FDT_ERR_BADMAGIC, -FDT_ERR_BADVERSION, -FDT_ERR_BADSTATE, standard meanings