pub unsafe extern "C" fn fdt_stringlist_contains(
strlist: *const c_char,
listlen: c_int,
str_: *const c_char,
) -> c_intExpand description
fdt_stringlist_contains - check a string list property for a string @strlist: Property containing a list of strings to check @listlen: Length of property @str: String to search for
This is a utility function provided for convenience. The list contains one or more strings, each terminated by \0, as is found in a device tree “compatible” property.
returns: 1 if the string is found in the list, 0 not found, or invalid list