pub unsafe extern "C" fn fdt_subnode_offset(
fdt: *const c_void,
parentoffset: c_int,
name: *const c_char,
) -> c_intExpand description
fdt_subnode_offset - find a subnode of a given node @fdt: pointer to the device tree blob @parentoffset: structure block offset of a node @name: name of the subnode to locate
fdt_subnode_offset() finds a subnode of the node at structure block offset parentoffset with the given name. name may include a unit address, in which case fdt_subnode_offset() will find the subnode with that unit address, or the unit address may be omitted, in which case fdt_subnode_offset() will find an arbitrary subnode whose name excluding unit address matches the given name.
returns: structure block offset of the requested subnode (>=0), on success -FDT_ERR_NOTFOUND, if the requested subnode does not exist -FDT_ERR_BADOFFSET, if parentoffset did not point to an FDT_BEGIN_NODE tag -FDT_ERR_BADMAGIC, -FDT_ERR_BADVERSION, -FDT_ERR_BADSTATE, -FDT_ERR_BADSTRUCTURE, -FDT_ERR_TRUNCATED, standard meanings.